# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: System.util.zlib

class Deflate:  # Class
    ...

class JZlib:  # Class
    def __init__(self) -> None: ...

    Z_BEST_COMPRESSION: int = ...  # static # readonly
    Z_BEST_SPEED: int = ...  # static # readonly
    Z_BUF_ERROR: int = ...  # static # readonly
    Z_DATA_ERROR: int = ...  # static # readonly
    Z_DEFAULT_COMPRESSION: int = ...  # static # readonly
    Z_DEFAULT_STRATEGY: int = ...  # static # readonly
    Z_ERRNO: int = ...  # static # readonly
    Z_FILTERED: int = ...  # static # readonly
    Z_FINISH: int = ...  # static # readonly
    Z_FULL_FLUSH: int = ...  # static # readonly
    Z_HUFFMAN_ONLY: int = ...  # static # readonly
    Z_MEM_ERROR: int = ...  # static # readonly
    Z_NEED_DICT: int = ...  # static # readonly
    Z_NO_COMPRESSION: int = ...  # static # readonly
    Z_NO_FLUSH: int = ...  # static # readonly
    Z_OK: int = ...  # static # readonly
    Z_PARTIAL_FLUSH: int = ...  # static # readonly
    Z_STREAM_END: int = ...  # static # readonly
    Z_STREAM_ERROR: int = ...  # static # readonly
    Z_SYNC_FLUSH: int = ...  # static # readonly
    Z_VERSION_ERROR: int = ...  # static # readonly

    @staticmethod
    def version() -> str: ...

class ZDeflaterOutputStream(System.IDisposable, System.IO.Stream):  # Class
    @overload
    def __init__(self, outp: System.IO.Stream) -> None: ...
    @overload
    def __init__(self, outp: System.IO.Stream, level: int) -> None: ...
    @overload
    def __init__(self, outp: System.IO.Stream, level: int, nowrap: bool) -> None: ...

    CanRead: bool  # readonly
    CanSeek: bool  # readonly
    CanWrite: bool  # readonly
    Length: int  # readonly
    Position: int

    def Read(self, buffer: List[int], offset: int, count: int) -> int: ...
    def Write(self, b: List[int], off: int, len: int) -> None: ...
    def Flush(self) -> None: ...
    def WriteByte(self, b: int) -> None: ...
    def Finish(self) -> None: ...
    def SetLength(self, value_: int) -> None: ...
    def End(self) -> None: ...
    def Close(self) -> None: ...
    def Seek(self, offset: int, origin: System.IO.SeekOrigin) -> int: ...

class ZInflaterInputStream(System.IDisposable, System.IO.Stream):  # Class
    @overload
    def __init__(self, inp: System.IO.Stream) -> None: ...
    @overload
    def __init__(self, inp: System.IO.Stream, nowrap: bool) -> None: ...

    CanRead: bool  # readonly
    CanSeek: bool  # readonly
    CanWrite: bool  # readonly
    Length: int  # readonly
    Position: int

    def Read(self, b: List[int], off: int, len: int) -> int: ...
    def Write(self, b: List[int], off: int, len: int) -> None: ...
    def Flush(self) -> None: ...
    def WriteByte(self, b: int) -> None: ...
    def ReadByte(self) -> int: ...
    def SetLength(self, value_: int) -> None: ...
    def Close(self) -> None: ...
    def Seek(self, offset: int, origin: System.IO.SeekOrigin) -> int: ...

class ZInputStream(System.IDisposable, System.IO.Stream):  # Class
    @overload
    def __init__(self, input: System.IO.Stream) -> None: ...
    @overload
    def __init__(self, input: System.IO.Stream, nowrap: bool) -> None: ...
    @overload
    def __init__(self, input: System.IO.Stream, level: int) -> None: ...

    CanRead: bool  # readonly
    CanSeek: bool  # readonly
    CanWrite: bool  # readonly
    FlushMode: int
    Length: int  # readonly
    Position: int
    TotalIn: int  # readonly
    TotalOut: int  # readonly

    def Read(self, b: List[int], off: int, len: int) -> int: ...
    def Write(self, buffer: List[int], offset: int, count: int) -> None: ...
    def Flush(self) -> None: ...
    def ReadByte(self) -> int: ...
    def SetLength(self, value_: int) -> None: ...
    def Close(self) -> None: ...
    def Seek(self, offset: int, origin: System.IO.SeekOrigin) -> int: ...

class ZOutputStream(System.IDisposable, System.IO.Stream):  # Class
    @overload
    def __init__(self, output: System.IO.Stream) -> None: ...
    @overload
    def __init__(self, output: System.IO.Stream, level: int) -> None: ...
    @overload
    def __init__(self, output: System.IO.Stream, level: int, nowrap: bool) -> None: ...

    CanRead: bool  # readonly
    CanSeek: bool  # readonly
    CanWrite: bool  # readonly
    FlushMode: int
    Length: int  # readonly
    Position: int
    TotalIn: int  # readonly
    TotalOut: int  # readonly

    def Read(self, buffer: List[int], offset: int, count: int) -> int: ...
    def Write(self, b: List[int], off: int, len: int) -> None: ...
    def Flush(self) -> None: ...
    def WriteByte(self, b: int) -> None: ...
    def Finish(self) -> None: ...
    def SetLength(self, value_: int) -> None: ...
    def End(self) -> None: ...
    def Close(self) -> None: ...
    def Seek(self, offset: int, origin: System.IO.SeekOrigin) -> int: ...

class ZStream:  # Class
    def __init__(self) -> None: ...

    adler: int
    avail_in: int
    avail_out: int
    msg: str
    next_in: List[int]
    next_in_index: int
    next_out: List[int]
    next_out_index: int
    total_in: int
    total_out: int

    @overload
    def deflateInit(self, level: int) -> int: ...
    @overload
    def deflateInit(self, level: int, nowrap: bool) -> int: ...
    @overload
    def deflateInit(self, level: int, bits: int) -> int: ...
    @overload
    def deflateInit(self, level: int, bits: int, nowrap: bool) -> int: ...
    def deflateSetDictionary(self, dictionary: List[int], dictLength: int) -> int: ...
    def deflate(self, flush: int) -> int: ...
    @overload
    def inflateInit(self) -> int: ...
    @overload
    def inflateInit(self, nowrap: bool) -> int: ...
    @overload
    def inflateInit(self, w: int) -> int: ...
    @overload
    def inflateInit(self, w: int, nowrap: bool) -> int: ...
    def inflateEnd(self) -> int: ...
    def inflateSync(self) -> int: ...
    def deflateParams(self, level: int, strategy: int) -> int: ...
    def free(self) -> None: ...
    def inflate(self, f: int) -> int: ...
    def inflateSetDictionary(self, dictionary: List[int], dictLength: int) -> int: ...
    def deflateEnd(self) -> int: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .ViewModel import IControlPanelViewModel, IManageViewModel, ITask, ITaskGroup

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Manage

class ConfigurationItem:  # Class
    def __init__(self) -> None: ...

    IsEnabled: bool
    Name: str  # readonly

class CopyConfigurationWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self, model: IManageViewModel) -> None: ...
    def InitializeComponent(self) -> None: ...

class DeployWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class DeploymentViewModel(System.Windows.DependencyObject):  # Class
    def __init__(self, rootModel: IControlPanelViewModel) -> None: ...

    DestinationProperty: System.Windows.DependencyProperty  # static
    EmbedConfigurationsProperty: System.Windows.DependencyProperty  # static
    LinkConfigurationsProperty: System.Windows.DependencyProperty  # static

    BrowseDestinationCommand: System.Windows.Input.ICommand  # readonly
    CommandDeploy: System.Windows.Input.ICommand  # readonly
    Configurations: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Manage.ConfigurationItem
    ]  # readonly
    Destination: str
    EmbedConfigurations: bool
    LinkConfigurations: bool

    def DoDeploy(self, parameter: Any) -> None: ...
    def ShowDialog(self, parent: System.Windows.Window) -> None: ...

class ManageGroup(ITaskGroup):  # Class
    def __init__(self, rootModel: IControlPanelViewModel) -> None: ...

    IsEnabled: bool  # readonly
    Tasks: List[ITask]  # readonly
    Title: str  # readonly

class ManageView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class ManageViewModel(
    System.Windows.DependencyObject, IManageViewModel, ITask
):  # Class
    def __init__(self, rootModel: IControlPanelViewModel) -> None: ...

    CommandCopyConfiguration: System.Windows.Input.ICommand  # readonly
    CommandDeleteConfiguration: System.Windows.Input.ICommand  # readonly
    CommandEditConfiguration: System.Windows.Input.ICommand  # readonly
    CommandNewConfiguration: System.Windows.Input.ICommand  # readonly
    CommandTest: System.Windows.Input.ICommand  # readonly
    Content: System.Windows.UIElement  # readonly
    IsEnabled: bool  # readonly
    RootModel: IControlPanelViewModel  # readonly
    Title: str  # readonly

    @overload
    def DeleteSelectedConfiguration(self, parameter: Any) -> None: ...
    @overload
    def DeleteSelectedConfiguration(self) -> None: ...
    def CreateNewConfiguration(
        self,
        parent: System.Windows.Window,
        folderName: str,
        instrument: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
    ) -> bool: ...
    def Deploy(self) -> None: ...
    def Leaving(self) -> bool: ...
    def CopyConfiguration(
        self, parent: System.Windows.Window, copyFrom: str, copyTo: str
    ) -> bool: ...
    @overload
    def BrowseStartupRootFolder(self, parameter: Any) -> None: ...
    @overload
    def BrowseStartupRootFolder(self) -> None: ...
    def Activate(self) -> None: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...

class NativeMethods:  # Class
    FOF_ALLOWUNDO: int = ...  # static # readonly
    FOF_NOCONFIRMATION: int = ...  # static # readonly
    FO_COPY: int = ...  # static # readonly
    FO_DELETE: int = ...  # static # readonly
    FO_MOVE: int = ...  # static # readonly
    FO_RENAME: int = ...  # static # readonly

    @staticmethod
    def SHFileOperation(
        lpFileOp: Agilent.MassHunter.Quantitative.Startup.Edit.Manage.SHFILEOPSTRUCT,
    ) -> int: ...

class NewConfigurationWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self, model: IManageViewModel) -> None: ...
    def InitializeComponent(self) -> None: ...

class SHFILEOPSTRUCT:  # Struct
    fAnyOperationsAborted: int
    fFlags: int
    hNameMappings: System.IntPtr
    hwnd: System.IntPtr
    lpszProgressTitle: str
    pFrom: System.IntPtr
    pTo: System.IntPtr
    wFunc: int

class ToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.PlotControl

class Axis(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        container: Agilent.MassHunter.Quantitative.PlotControl.IAxisContainer,
        location: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation,
    ) -> None: ...

    LabelColorProperty: System.Windows.DependencyProperty  # static
    LineColorProperty: System.Windows.DependencyProperty  # static
    MaxValueProperty: System.Windows.DependencyProperty  # static
    MinValueProperty: System.Windows.DependencyProperty  # static
    TickLabelFormatProperty: System.Windows.DependencyProperty  # static
    TickLabelVerticalProperty: System.Windows.DependencyProperty  # static
    TitleLocationProperty: System.Windows.DependencyProperty  # static
    TitleProperty: System.Windows.DependencyProperty  # static
    VisibilityProperty: System.Windows.DependencyProperty  # static

    IsLog: bool
    LabelColor: System.Windows.Media.Color
    LineColor: System.Windows.Media.Color
    Location: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation  # readonly
    MaxValue: float
    MinValue: float
    TickLabelExponential: bool
    TickLabelFormat: str
    TickLabelVertical: bool
    Title: str
    TitleLocation: Agilent.MassHunter.Quantitative.PlotControl.TitleLocation
    Visibility: System.Windows.Visibility

    def Render(
        self,
        gr: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        clipRect: System.Windows.Rect,
        rect: System.Windows.Rect,
    ) -> None: ...
    def CalcHeight(self) -> float: ...

class AxisLabelInfo:  # Class
    def __init__(self) -> None: ...

    Brush: System.Windows.Media.Brush
    CultureInfo: System.Globalization.CultureInfo
    ExponentialTickLabel: bool
    FlowDirection: System.Windows.FlowDirection
    FontSize: float
    GridlineMode: Agilent.MassHunter.Quantitative.PlotControl.GridlineMode
    Location: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation
    PlotControl: Agilent.MassHunter.Quantitative.PlotControl.PlotControl
    TickLabelFormat: str
    TickSize: float
    TypeFace: System.Windows.Media.Typeface

    def GetTickLabel(self, value_: float) -> str: ...

class AxisLocation(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Bottom: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation = (
        ...
    )  # static # readonly
    Left: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation = (
        ...
    )  # static # readonly
    Right: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation = (
        ...
    )  # static # readonly
    Top: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation = (
        ...
    )  # static # readonly

class ClipState(Agilent.MassHunter.Quantitative.PlotControl.GraphicsState):  # Class
    def __init__(self, clip: System.Windows.Rect) -> None: ...
    def Push(self, canvas: iTextSharp.text.pdf.PdfContentByte) -> None: ...
    def Pop(self, canvas: iTextSharp.text.pdf.PdfContentByte) -> None: ...

class DrawAxis:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def CalcHorizontalAxisHeight(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        labelInfo: Agilent.MassHunter.Quantitative.PlotControl.AxisLabelInfo,
    ) -> float: ...
    @staticmethod
    def DrawXAxis(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        clipRect: System.Windows.Rect,
        rect: System.Windows.Rect,
        minValue: float,
        maxValue: float,
        pen: System.Windows.Media.Pen,
        labelInfo: Agilent.MassHunter.Quantitative.PlotControl.AxisLabelInfo,
    ) -> None: ...
    @staticmethod
    def DrawXAxisLog(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        clipRect: System.Windows.Rect,
        rect: System.Windows.Rect,
        minValue: float,
        maxValue: float,
        pen: System.Windows.Media.Pen,
        labelInfo: Agilent.MassHunter.Quantitative.PlotControl.AxisLabelInfo,
    ) -> None: ...
    @staticmethod
    def CalcTickIntervalLog(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        minValue: float,
        maxValue: float,
        labelInfo: Agilent.MassHunter.Quantitative.PlotControl.AxisLabelInfo,
        areaWidth: float,
        start: float,
        factor: float,
    ) -> None: ...
    @staticmethod
    def CalcTickInterval(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        minValue: float,
        maxValue: float,
        labelInfo: Agilent.MassHunter.Quantitative.PlotControl.AxisLabelInfo,
        areaSize: System.Windows.Size,
        orientation: System.Windows.Controls.Orientation,
        desiredSize: float,
    ) -> float: ...
    @staticmethod
    def MeasureVerticalTickLabels(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        minValue: float,
        maxValue: float,
        interval: float,
        labelInfo: Agilent.MassHunter.Quantitative.PlotControl.AxisLabelInfo,
        areaHeight: float,
    ) -> float: ...
    @staticmethod
    def DrawYAxis(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        clipRect: System.Windows.Rect,
        rect: System.Windows.Rect,
        minValue: float,
        maxValue: float,
        pen: System.Windows.Media.Pen,
        labelInfo: Agilent.MassHunter.Quantitative.PlotControl.AxisLabelInfo,
    ) -> None: ...

class DrawPeakLabels:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def DrawStringBottomUp(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        text: str,
        culture: System.Globalization.CultureInfo,
        flow: System.Windows.FlowDirection,
        typeface: System.Windows.Media.Typeface,
        emSize: float,
        brush: System.Windows.Media.Brush,
        alignment: System.Windows.TextAlignment,
        trimming: System.Windows.TextTrimming,
        pos: System.Windows.Point,
    ) -> None: ...
    @staticmethod
    def DrawNonOverlap(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        peaks: Agilent.MassHunter.Quantitative.PlotControl.IPeaks,
        drawInfo: Agilent.MassHunter.Quantitative.PlotControl.DrawPeakLabelsInfo,
        dataRect: System.Windows.Rect,
        rect: System.Windows.Rect,
        clipRect: System.Windows.Rect,
    ) -> None: ...

class DrawPeakLabelsInfo:  # Class
    def __init__(self) -> None: ...

    CultureInfo: System.Globalization.CultureInfo
    FontSize: float
    Typeface: System.Windows.Media.Typeface
    Vertical: bool

class DrawPlot:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def DrawLog(
        gr: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        pen: System.Windows.Media.Pen,
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
        minX: float,
        maxX: float,
        minY: float,
        maxY: float,
        rect: System.Windows.Rect,
    ) -> None: ...
    @overload
    @staticmethod
    def FindNearestIndex(
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries, x: float
    ) -> int: ...
    @overload
    @staticmethod
    def FindNearestIndex(
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
        x: float,
        start: int,
        end: int,
    ) -> int: ...
    @staticmethod
    def GetSnapPoint(
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries, sx: float
    ) -> Optional[System.Windows.Point]: ...
    @staticmethod
    def DrawBar(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
        bar: Agilent.MassHunter.Quantitative.PlotControl.IPlotBar,
        minX: float,
        maxX: float,
        minY: float,
        maxY: float,
        rect: System.Windows.Rect,
    ) -> None: ...
    @staticmethod
    def CoordinateToDataY(
        coord: float, minData: float, maxData: float, minCoord: float, maxCoord: float
    ) -> float: ...
    @staticmethod
    def CoordinateToDataX(
        coord: float, minData: float, maxData: float, minCoord: float, maxCoord: float
    ) -> float: ...
    @staticmethod
    def Draw(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        pen: System.Windows.Media.Pen,
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
        minX: float,
        maxX: float,
        minY: float,
        maxY: float,
        rect: System.Windows.Rect,
        drawVertical: bool,
    ) -> None: ...
    @staticmethod
    def DrawSpectrum(
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        pen: System.Windows.Media.Pen,
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
        minX: float,
        maxX: float,
        minY: float,
        maxY: float,
        rect: System.Windows.Rect,
    ) -> None: ...
    @staticmethod
    def DataToCoordinateLog(
        data: float, minData: float, maxData: float, minCoord: float, maxCoord: float
    ) -> float: ...
    @staticmethod
    def DataToCoordinateY(
        data: float, minData: float, maxData: float, minCoord: float, maxCoord: float
    ) -> float: ...
    @staticmethod
    def DataToCoordinateX(
        data: float, minData: float, maxData: float, minCoord: float, maxCoord: float
    ) -> float: ...

class DrawingContextGraphics(
    System.IDisposable, Agilent.MassHunter.Quantitative.PlotControl.IGraphics
):  # Class
    def __init__(self, dc: System.Windows.Media.DrawingContext) -> None: ...
    def DrawRectangle(
        self,
        brush: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        rectangle: System.Windows.Rect,
    ) -> None: ...
    @overload
    def DrawText(
        self,
        ft: System.Windows.Media.FormattedText,
        brush: System.Windows.Media.Brush,
        p: System.Windows.Point,
    ) -> None: ...
    @overload
    def DrawText(
        self,
        text: str,
        culture: System.Globalization.CultureInfo,
        flow: System.Windows.FlowDirection,
        typeface: System.Windows.Media.Typeface,
        emSize: float,
        brush: System.Windows.Media.Brush,
        alignment: System.Windows.TextAlignment,
        trimming: System.Windows.TextTrimming,
        maxTextWidth: Optional[float],
        pos: System.Windows.Point,
    ) -> None: ...
    def DrawPolyline(
        self, pen: System.Windows.Media.Pen, points: List[System.Windows.Point]
    ) -> None: ...
    def DrawEllipse(
        self,
        br: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        center: System.Windows.Point,
        radiusX: float,
        radiusY: float,
    ) -> None: ...
    def DrawLine(
        self,
        pen: System.Windows.Media.Pen,
        s: System.Windows.Point,
        e: System.Windows.Point,
    ) -> None: ...
    def DrawPolygon(
        self,
        br: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        points: List[System.Windows.Point],
    ) -> None: ...
    def Pop(self) -> None: ...
    def PushClip(self, rect: System.Windows.Rect) -> None: ...
    def PushGuidelineSet(self, gs: System.Windows.Media.GuidelineSet) -> None: ...
    def PushTransform(self, t: System.Windows.Media.Transform) -> None: ...
    def Dispose(self) -> None: ...
    @overload
    def MeasureString(
        self, text: str, typeface: System.Windows.Media.Typeface, size: float
    ) -> System.Windows.Size: ...
    @overload
    def MeasureString(
        self,
        text: str,
        typeface: System.Windows.Media.Typeface,
        size: float,
        width: float,
    ) -> System.Windows.Size: ...

class GraphicsState:  # Class
    def __init__(self) -> None: ...
    def Push(self, canvas: iTextSharp.text.pdf.PdfContentByte) -> None: ...
    def Pop(self, canvas: iTextSharp.text.pdf.PdfContentByte) -> None: ...

class GridPlotBehavior(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.Behavior[
        Agilent.MassHunter.Quantitative.PlotControl.GridPlotContent
    ],
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    def __init__(self) -> None: ...

class GridPlotContent(
    System.Windows.Controls.Primitives.IScrollInfo,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Controls.Control,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    AxisLabelBrushProperty: System.Windows.DependencyProperty  # static # readonly
    AxisLineBrushProperty: System.Windows.DependencyProperty  # static # readonly
    ColumnOffsetProperty: System.Windows.DependencyProperty  # static # readonly
    DataSourceProperty: System.Windows.DependencyProperty  # static # readonly
    LinkAxesXProperty: System.Windows.DependencyProperty  # static # readonly
    NumColumnsPerPageProperty: System.Windows.DependencyProperty  # static # readonly
    NumRowsPerPageProperty: System.Windows.DependencyProperty  # static # readonly
    PaneBorderBrushProperty: System.Windows.DependencyProperty  # static # readonly
    PaneBorderThicknessProperty: System.Windows.DependencyProperty  # static # readonly
    PaneMarginProperty: System.Windows.DependencyProperty  # static # readonly
    PaneSelectionModeProperty: System.Windows.DependencyProperty  # static # readonly
    RowOffsetProperty: System.Windows.DependencyProperty  # static # readonly
    SelectedPaneBorderBrushProperty: (
        System.Windows.DependencyProperty
    )  # static # readonly
    TickLabelFontSizeProperty: System.Windows.DependencyProperty  # static # readonly
    TickSizeProperty: System.Windows.DependencyProperty  # static # readonly
    TitleFontSizeProperty: System.Windows.DependencyProperty  # static # readonly

    AxisLabelBrush: System.Windows.Media.Brush
    AxisLineBrush: System.Windows.Media.Brush
    CanHorizontallyScroll: bool
    CanVerticallyScroll: bool
    ColumnOffset: int
    DataSource: System.Array[Any]
    ExtentHeight: float  # readonly
    ExtentWidth: float  # readonly
    HorizontalOffset: float  # readonly
    def __getitem__(
        self, rowIndex: int, columnIndex: int
    ) -> Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane: ...
    def __setitem__(
        self,
        rowIndex: int,
        columnIndex: int,
        value_: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
    ) -> None: ...
    LinkAxesX: bool
    NumColumns: int  # readonly
    NumColumnsPerPage: int
    NumRows: int  # readonly
    NumRowsPerPage: int
    PaneBorderBrush: System.Windows.Media.Brush
    PaneBorderThickness: float
    PaneMargin: float
    PaneSelectionMode: Agilent.MassHunter.Quantitative.PlotControl.PaneSelectionMode
    RowOffset: int
    ScrollOwner: System.Windows.Controls.ScrollViewer
    SelectedPaneBorderBrush: System.Windows.Media.Brush
    TickLabelFontSize: float
    TickSize: float
    TitleExtent: float
    TitleFontSize: float
    VerticalOffset: float  # readonly
    ViewportHeight: float  # readonly
    ViewportWidth: float  # readonly
    XAxisExtent: float
    YAxisExtent: float

    def DrawPage(
        self,
        drawingContext: System.Windows.Media.DrawingContext,
        rect: System.Windows.Rect,
        rowOffset: int,
        columnOffset: int,
        numRowsPerPage: int,
        numColumnsPerPage: int,
    ) -> None: ...
    def AutoScalePaneY(
        self, pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane
    ) -> None: ...
    def UnselectAllPanes(self) -> None: ...
    def DrawPane(
        self,
        drawingContext: System.Windows.Media.DrawingContext,
        rect: System.Windows.Rect,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        dataSource: Any,
    ) -> None: ...
    def GetLinkedRangeX(
        self, index: int
    ) -> Agilent.MassHunter.Quantitative.PlotControl.LinkedRange: ...
    def GetAutoScaleRange(
        self,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        vertical: bool,
    ) -> Agilent.MassHunter.Quantitative.PlotControl.Range: ...
    def ShiftSelectPanes(
        self, pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane
    ) -> None: ...
    def UpdateDimension(self) -> None: ...
    def SelectPane(
        self,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        select: bool,
        add: bool,
    ) -> None: ...
    def LineLeft(self) -> None: ...
    def PageLeft(self) -> None: ...
    def DrawBaseline(
        self,
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        rect: System.Windows.Rect,
        sx: float,
        sy: float,
        ex: float,
        ey: float,
        pen: System.Windows.Media.Pen,
    ) -> List[System.Windows.Point]: ...
    def PageRight(self) -> None: ...
    def PageUp(self) -> None: ...
    def PageDown(self) -> None: ...
    def MakeVisible(
        self, visual: System.Windows.Media.Visual, rectangle: System.Windows.Rect
    ) -> System.Windows.Rect: ...
    def AutoScalePaneX(
        self, pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane
    ) -> None: ...
    def LineUp(self) -> None: ...
    def LineDown(self) -> None: ...
    def SetHorizontalOffset(self, offset: float) -> None: ...
    def LineRight(self) -> None: ...
    def GetSelectedPanes(
        self,
    ) -> List[Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane]: ...
    def MouseWheelLeft(self) -> None: ...
    def EnsurePaneVisible(self, row: int, column: int) -> None: ...
    def MouseWheelRight(self) -> None: ...
    def MouseWheelUp(self) -> None: ...
    def SetVerticalOffset(self, offset: float) -> None: ...
    def GetPaneFromPoint(
        self, point: System.Windows.Point
    ) -> Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane: ...
    def MouseWheelDown(self) -> None: ...

class GridPlotHitTest:  # Struct
    Location: Agilent.MassHunter.Quantitative.PlotControl.HitTestLocation
    Pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane

class GridPlotPane(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        content: Agilent.MassHunter.Quantitative.PlotControl.GridPlotContent,
        row: int,
        column: int,
    ) -> None: ...

    MaxXProperty: System.Windows.DependencyProperty  # static # readonly
    MaxYProperty: System.Windows.DependencyProperty  # static # readonly
    MinXProperty: System.Windows.DependencyProperty  # static # readonly
    MinYProperty: System.Windows.DependencyProperty  # static # readonly

    Bounds: System.Windows.Rect  # readonly
    Column: int  # readonly
    IsSelected: bool
    MaxX: float
    MaxY: float
    MinX: float
    MinY: float
    PlotAreaBounds: System.Windows.Rect  # readonly
    Row: int  # readonly
    Title: str
    TitleBounds: System.Windows.Rect  # readonly
    XAxisBounds: System.Windows.Rect  # readonly
    YAxisBounds: System.Windows.Rect  # readonly

class GridPlotShiftAxisAdorner(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Documents.Adorner,
):  # Class
    def __init__(
        self,
        plot: Agilent.MassHunter.Quantitative.PlotControl.GridPlotContent,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        start: System.Windows.Point,
        vertical: bool,
    ) -> None: ...

class GridPlotStretchAxisAdorner(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Documents.Adorner,
):  # Class
    def __init__(
        self,
        plot: Agilent.MassHunter.Quantitative.PlotControl.GridPlotContent,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        startPoint: System.Windows.Point,
        vertical: bool,
    ) -> None: ...

class GridPlotZoomAdorner(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Documents.Adorner,
):  # Class
    def __init__(
        self,
        plot: Agilent.MassHunter.Quantitative.PlotControl.GridPlotContent,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        startPoint: System.Windows.Point,
    ) -> None: ...

class GridlineMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Visible: Agilent.MassHunter.Quantitative.PlotControl.GridlineMode = (
        ...
    )  # static # readonly
    ZeroLineOnly: Agilent.MassHunter.Quantitative.PlotControl.GridlineMode = (
        ...
    )  # static # readonly

class HitTestLocation(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    PlotArea: Agilent.MassHunter.Quantitative.PlotControl.HitTestLocation = (
        ...
    )  # static # readonly
    Title: Agilent.MassHunter.Quantitative.PlotControl.HitTestLocation = (
        ...
    )  # static # readonly
    XAxis: Agilent.MassHunter.Quantitative.PlotControl.HitTestLocation = (
        ...
    )  # static # readonly
    YAxis: Agilent.MassHunter.Quantitative.PlotControl.HitTestLocation = (
        ...
    )  # static # readonly

class IAxisContainer(object):  # Interface
    FontSize: float  # readonly

    def RecalcRects(self) -> None: ...
    def Invalidate(self) -> None: ...
    def CreateTypeface(self) -> System.Windows.Media.Typeface: ...

class IGraphics(object):  # Interface
    def DrawRectangle(
        self,
        brush: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        rectangle: System.Windows.Rect,
    ) -> None: ...
    def DrawText(
        self,
        text: str,
        culture: System.Globalization.CultureInfo,
        flow: System.Windows.FlowDirection,
        typeface: System.Windows.Media.Typeface,
        emSize: float,
        brush: System.Windows.Media.Brush,
        alignment: System.Windows.TextAlignment,
        trimming: System.Windows.TextTrimming,
        maxTextWidth: Optional[float],
        pos: System.Windows.Point,
    ) -> None: ...
    def DrawPolyline(
        self, pen: System.Windows.Media.Pen, points: List[System.Windows.Point]
    ) -> None: ...
    def DrawEllipse(
        self,
        br: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        center: System.Windows.Point,
        radiusX: float,
        radiusY: float,
    ) -> None: ...
    def DrawLine(
        self,
        pen: System.Windows.Media.Pen,
        s: System.Windows.Point,
        e: System.Windows.Point,
    ) -> None: ...
    def DrawPolygon(
        self,
        brush: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        points: List[System.Windows.Point],
    ) -> None: ...
    def Pop(self) -> None: ...
    def PushClip(self, rect: System.Windows.Rect) -> None: ...
    def PushGuidelineSet(self, gs: System.Windows.Media.GuidelineSet) -> None: ...
    def PushTransform(self, transform: System.Windows.Media.Transform) -> None: ...
    @overload
    def MeasureString(
        self, text: str, typeface: System.Windows.Media.Typeface, emSize: float
    ) -> System.Windows.Size: ...
    @overload
    def MeasureString(
        self,
        text: str,
        typeface: System.Windows.Media.Typeface,
        emSize: float,
        width: float,
    ) -> System.Windows.Size: ...

class IPeaks(object):  # Interface
    PeakCount: int  # readonly
    PeakLabelsVisible: bool  # readonly

    def GetPeakBaselinePen(self, index: int) -> System.Windows.Media.Pen: ...
    def GetPeakLabel(self, index: int) -> str: ...
    def GetPeak(self, index: int) -> System.Windows.Point: ...
    def GetPeakLabelBrush(self, index: int) -> System.Windows.Media.Brush: ...
    def GetPeakFillBrush(self, index: int) -> System.Windows.Media.Brush: ...
    def GetBaseline(
        self, index: int, start: System.Windows.Point, end: System.Windows.Point
    ) -> None: ...

class IPlotBar(object):  # Interface
    def GetBarRange(self, index: int, start: float, end: float) -> None: ...
    def GetFillBrush(self, index: int) -> System.Windows.Media.Brush: ...
    def GetLinePen(self, index: int) -> System.Windows.Media.Pen: ...

class IPlotSeries(object):  # Interface
    Count: int  # readonly
    Pen: System.Windows.Media.Pen  # readonly
    PlotMode: Agilent.MassHunter.Quantitative.PlotControl.PlotMode  # readonly
    Visible: bool  # readonly

    def GetPoint(self, index: int, x: float, y: float) -> None: ...

class IZoomHistory(object):  # Interface
    CanRezoom: bool  # readonly
    CanUnzoom: bool  # readonly
    Capacity: int

    def Push(self) -> None: ...
    def Clear(self) -> None: ...
    def Rezoom(self) -> None: ...
    def Unzoom(self) -> None: ...

class LinkedRange(System.Windows.DependencyObject):  # Class
    def __init__(self) -> None: ...

    MaxValueProperty: System.Windows.DependencyProperty  # static # readonly
    MinValueProperty: System.Windows.DependencyProperty  # static # readonly

    MaxBinding: System.Windows.Data.Binding  # readonly
    MaxValue: float
    MinBinding: System.Windows.Data.Binding  # readonly
    MinValue: float

class MS(System.IO.MemoryStream, System.IDisposable):  # Class
    def __init__(self) -> None: ...

class PDFGraphics(
    System.IDisposable, Agilent.MassHunter.Quantitative.PlotControl.IGraphics
):  # Class
    def __init__(
        self,
        canvas: iTextSharp.text.pdf.PdfContentByte,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...

    IgnoreFontName: bool

    @staticmethod
    def RegisterFont(name: str) -> None: ...
    def DrawRectangle(
        self,
        brush: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        rectangle: System.Windows.Rect,
    ) -> None: ...
    @overload
    def DrawText(
        self,
        ft: System.Windows.Media.FormattedText,
        brush: System.Windows.Media.Brush,
        pos: System.Windows.Point,
    ) -> None: ...
    @overload
    def DrawText(
        self,
        text: str,
        culture: System.Globalization.CultureInfo,
        flow: System.Windows.FlowDirection,
        typeface: System.Windows.Media.Typeface,
        emSize: float,
        brush: System.Windows.Media.Brush,
        alignment: System.Windows.TextAlignment,
        trimming: System.Windows.TextTrimming,
        maxTextWidth: Optional[float],
        pos: System.Windows.Point,
    ) -> None: ...
    def DrawPolyline(
        self, pen: System.Windows.Media.Pen, points: List[System.Windows.Point]
    ) -> None: ...
    def DrawEllipse(
        self,
        br: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        center: System.Windows.Point,
        radiusX: float,
        radiusY: float,
    ) -> None: ...
    def DrawLine(
        self,
        pen: System.Windows.Media.Pen,
        s: System.Windows.Point,
        e: System.Windows.Point,
    ) -> None: ...
    def DrawPolygon(
        self,
        brush: System.Windows.Media.Brush,
        pen: System.Windows.Media.Pen,
        points: List[System.Windows.Point],
    ) -> None: ...
    def Pop(self) -> None: ...
    def PushClip(self, rect: System.Windows.Rect) -> None: ...
    def PushGuidelineSet(self, gs: System.Windows.Media.GuidelineSet) -> None: ...
    def WPFtoPDF(
        self, element: System.Windows.FrameworkElement, w: float, h: float
    ) -> iTextSharp.text.Image: ...
    def PushTransform(self, transform: System.Windows.Media.Transform) -> None: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def FindFontFile(name: str, index: int) -> str: ...
    @overload
    def MeasureString(
        self, text: str, typeface: System.Windows.Media.Typeface, emSize: float
    ) -> System.Windows.Size: ...
    @overload
    def MeasureString(
        self,
        text: str,
        typeface: System.Windows.Media.Typeface,
        emSize: float,
        width: float,
    ) -> System.Windows.Size: ...

class PaneAxis(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.Control,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IFrameworkInputElement,
):  # Class
    def __init__(self) -> None: ...

    AxisLocationProperty: System.Windows.DependencyProperty  # static # readonly
    ExponentialTickLabelProperty: System.Windows.DependencyProperty  # static # readonly
    GridlineModeProperty: System.Windows.DependencyProperty  # static # readonly
    LabelBrushProperty: System.Windows.DependencyProperty  # static # readonly
    LineBrushProperty: System.Windows.DependencyProperty  # static # readonly
    MaxProperty: System.Windows.DependencyProperty  # static # readonly
    MinProperty: System.Windows.DependencyProperty  # static # readonly

    Arranging: bool
    AutoScaleMax: float
    AutoScaleMin: float
    AxisLocation: Agilent.MassHunter.Quantitative.PlotControl.AxisLocation
    ExponentialTickLabel: bool
    GridlineMode: Agilent.MassHunter.Quantitative.PlotControl.GridlineMode
    IsVertical: bool  # readonly
    LabelBrush: System.Windows.Media.Brush
    LineBrush: System.Windows.Media.Brush
    Max: float
    MeasuringGraphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics
    Min: float
    PlotControl: Agilent.MassHunter.Quantitative.PlotControl.PlotControl

    def DoAutoScale(self) -> None: ...
    def RenderAxis(
        self,
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        rect: System.Windows.Rect,
    ) -> None: ...

    AutoScale: System.EventHandler[
        Agilent.MassHunter.Quantitative.PlotControl.RangeEventArgs
    ]  # Event

class PaneAxisShiftAdorner(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Documents.Adorner,
):  # Class
    def __init__(
        self,
        plotControl: Agilent.MassHunter.Quantitative.PlotControl.PlotControl,
        axis: Agilent.MassHunter.Quantitative.PlotControl.PaneAxis,
        startPoint: System.Windows.Point,
    ) -> None: ...

class PaneAxisStretchAdorner(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Documents.Adorner,
):  # Class
    def __init__(
        self,
        plotControl: Agilent.MassHunter.Quantitative.PlotControl.PlotControl,
        axis: Agilent.MassHunter.Quantitative.PlotControl.PaneAxis,
        startPoint: System.Windows.Point,
    ) -> None: ...

class PaneSelectionMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Multiple: Agilent.MassHunter.Quantitative.PlotControl.PaneSelectionMode = (
        ...
    )  # static # readonly
    Single: Agilent.MassHunter.Quantitative.PlotControl.PaneSelectionMode = (
        ...
    )  # static # readonly

class PlotAxesControl(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...

    BottomAxis: Agilent.MassHunter.Quantitative.PlotControl.PaneAxis  # readonly
    BottomAxisLabel: System.Windows.Controls.TextBlock  # readonly
    LeftAxis: Agilent.MassHunter.Quantitative.PlotControl.PaneAxis  # readonly
    LeftAxisLabel: System.Windows.Controls.TextBlock  # readonly
    PlotControl: Agilent.MassHunter.Quantitative.PlotControl.PlotControl  # readonly
    Title: System.Windows.FrameworkElement

    def ClearAllBindings(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    def RenderData(
        self,
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        rect: System.Windows.Rect,
    ) -> None: ...

class PlotAxesControlBehavior(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
    System.Windows.Interactivity.Behavior[
        Agilent.MassHunter.Quantitative.PlotControl.PlotAxesControl
    ],
):  # Class
    def __init__(self) -> None: ...

    StartPoint: Optional[System.Windows.Point]

class PlotControl(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.Control,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IFrameworkInputElement,
):  # Class
    def __init__(self) -> None: ...

    DataSourceProperty: System.Windows.DependencyProperty  # static # readonly
    GridlinesBrushProperty: System.Windows.DependencyProperty  # static # readonly
    MaxXProperty: System.Windows.DependencyProperty  # static # readonly
    MaxYProperty: System.Windows.DependencyProperty  # static # readonly
    MinXProperty: System.Windows.DependencyProperty  # static # readonly
    MinYProperty: System.Windows.DependencyProperty  # static # readonly
    XGridlinesValuesProperty: System.Windows.DependencyProperty  # static # readonly
    YGridlinesValuesProperty: System.Windows.DependencyProperty  # static # readonly

    Arranging: bool
    DataSource: Any
    GridlinesBrush: System.Windows.Media.Brush
    MaxX: float
    MaxY: float
    MinX: float
    MinY: float
    PeakLabelsVertical: bool
    XGridlinesValues: List[float]
    YGridlinesValues: List[float]
    ZoomHistory: Agilent.MassHunter.Quantitative.PlotControl.IZoomHistory  # readonly

    def RenderSeriesTo(
        self,
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
        rect: System.Windows.Rect,
    ) -> None: ...
    def RenderTo(
        self,
        graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics,
        rect: System.Windows.Rect,
    ) -> None: ...

    RenderData: System.EventHandler[
        Agilent.MassHunter.Quantitative.PlotControl.RenderDataEventArgs
    ]  # Event
    RenderSeries: System.EventHandler[
        Agilent.MassHunter.Quantitative.PlotControl.RenderSeriesEventArgs
    ]  # Event

class PlotControlZoomAdorner(
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    System.Windows.IInputElement,
    System.Windows.Markup.IQueryAmbient,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IHaveResources,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Documents.Adorner,
):  # Class
    def __init__(
        self,
        plot: Agilent.MassHunter.Quantitative.PlotControl.PlotControl,
        startPoint: System.Windows.Point,
    ) -> None: ...

class PlotControlZoomHistory(
    Agilent.MassHunter.Quantitative.PlotControl.IZoomHistory
):  # Class
    def __init__(
        self, plotControl: Agilent.MassHunter.Quantitative.PlotControl.PlotControl
    ) -> None: ...

    CanRezoom: bool  # readonly
    CanUnzoom: bool  # readonly
    Capacity: int

    def Push(self) -> None: ...
    def Clear(self) -> None: ...
    def Rezoom(self) -> None: ...
    def Unzoom(self) -> None: ...

class PlotMode(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Bar: Agilent.MassHunter.Quantitative.PlotControl.PlotMode = ...  # static # readonly
    Connected: Agilent.MassHunter.Quantitative.PlotControl.PlotMode = (
        ...
    )  # static # readonly
    Line: Agilent.MassHunter.Quantitative.PlotControl.PlotMode = (
        ...
    )  # static # readonly

class PlotPeakSeries(
    Agilent.MassHunter.Quantitative.PlotControl.PointArrayPlotSeries,
    Agilent.MassHunter.Quantitative.PlotControl.IPeaks,
    Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
):  # Class
    def __init__(self) -> None: ...

    PeakCount: int  # readonly
    PeakLabelsVisible: bool

    def GetPeakBaselinePen(self, index: int) -> System.Windows.Media.Pen: ...
    def GetPeakLabel(self, index: int) -> str: ...
    def AddPeak(
        self,
        location: System.Windows.Point,
        start: System.Windows.Point,
        end: System.Windows.Point,
        fillBrush: System.Windows.Media.Brush,
        baselinePen: System.Windows.Media.Pen,
        label: str,
        labelBrush: System.Windows.Media.Brush,
    ) -> None: ...
    def GetPeak(self, index: int) -> System.Windows.Point: ...
    def GetPeakLabelBrush(self, index: int) -> System.Windows.Media.Brush: ...
    def ClearPeaks(self) -> None: ...
    def GetPeakFillBrush(self, index: int) -> System.Windows.Media.Brush: ...
    def GetBaseline(
        self, index: int, start: System.Windows.Point, end: System.Windows.Point
    ) -> None: ...

class PointArrayPlotSeries(
    Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries
):  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    Offset: float
    Pen: System.Windows.Media.Pen
    PlotMode: Agilent.MassHunter.Quantitative.PlotControl.PlotMode
    Points: List[System.Windows.Point]
    Scale: float
    Tag: Any
    Visible: bool

    def GetPoint(self, index: int, x: float, y: float) -> None: ...
    @overload
    def Normalize(self, maxValue: float) -> None: ...
    @overload
    def Normalize(self, minValue: float, maxValue: float) -> None: ...

class Range:  # Class
    def __init__(self) -> None: ...

    Max: float
    Min: float

class RangeEventArgs(System.EventArgs):  # Class
    def __init__(self) -> None: ...

    Handled: bool
    Range: Agilent.MassHunter.Quantitative.PlotControl.Range

class RenderDataEventArgs(System.EventArgs):  # Class
    def __init__(self) -> None: ...

    Graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics  # readonly
    Handled: bool
    Rect: System.Windows.Rect  # readonly

class RenderSeriesEventArgs(System.EventArgs):  # Class
    def __init__(self) -> None: ...

    Graphics: Agilent.MassHunter.Quantitative.PlotControl.IGraphics  # readonly
    Handled: bool
    Rect: System.Windows.Rect  # readonly
    Series: Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries  # readonly

class TitleLocation(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Center: Agilent.MassHunter.Quantitative.PlotControl.TitleLocation = (
        ...
    )  # static # readonly
    Far: Agilent.MassHunter.Quantitative.PlotControl.TitleLocation = (
        ...
    )  # static # readonly
    Near: Agilent.MassHunter.Quantitative.PlotControl.TitleLocation = (
        ...
    )  # static # readonly

class TransformState(
    Agilent.MassHunter.Quantitative.PlotControl.GraphicsState
):  # Class
    def __init__(self, transform: System.Windows.Media.Transform) -> None: ...
    def Push(self, canvas: iTextSharp.text.pdf.PdfContentByte) -> None: ...
    def Pop(self, canvas: iTextSharp.text.pdf.PdfContentByte) -> None: ...

class Utils:  # Class
    @overload
    @staticmethod
    def HitTest(
        plot: Agilent.MassHunter.Quantitative.PlotControl.GridPlotContent,
        point: System.Windows.Point,
    ) -> Agilent.MassHunter.Quantitative.PlotControl.GridPlotHitTest: ...
    @overload
    @staticmethod
    def HitTest(
        control: Agilent.MassHunter.Quantitative.PlotControl.PlotAxesControl,
        position: System.Windows.Point,
    ) -> Agilent.MassHunter.Quantitative.PlotControl.HitTestLocation: ...
    @overload
    @staticmethod
    def HitTest(
        element: System.Windows.FrameworkElement, point: System.Windows.Point
    ) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Model
from .Model import IEventContext, IEventManipulator, IRubberBand

# Stubs for namespace: Agilent.MassSpectrometry.EventManipulating

class EventContext(System.IDisposable, IEventContext):  # Class
    def __init__(self) -> None: ...

    ControlCount: int  # readonly
    StackCount: int  # readonly
    Top: IEventManipulator  # readonly

    def RegisterControl(self, ctrl: System.Windows.Forms.Control) -> None: ...
    def RevokeControl(self, ctrl: System.Windows.Forms.Control) -> None: ...
    def Pop(self, em: IEventManipulator) -> None: ...
    def Peek(self, index: int) -> IEventManipulator: ...
    def Dispose(self) -> None: ...
    def Push(self, em: IEventManipulator) -> None: ...

class EventManipulator(System.IDisposable, IEventManipulator):  # Class
    EventContext: IEventContext  # readonly
    IsOnStack: bool  # readonly
    RubberBand: IRubberBand

    def OnMouseDown(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseDoubleClick(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnEnd(self) -> None: ...
    def OnMouseMove(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseUp(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnKeyDown(self, sender: Any, e: System.Windows.Forms.KeyEventArgs) -> None: ...
    def OnMouseWheel(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnStart(self) -> None: ...
    def Pop(self) -> None: ...
    def OnResume(self) -> None: ...
    def Dispose(self) -> None: ...
    def OnDoubleClick(self, sender: Any, e: System.EventArgs) -> None: ...
    def OnKeyUp(self, sender: Any, e: System.Windows.Forms.KeyEventArgs) -> None: ...
    def Push(self) -> None: ...
    def OnSuspend(self) -> None: ...

class RubberBand(IRubberBand, System.IDisposable):  # Class
    Control: System.Windows.Forms.Control  # readonly
    LastPoint: System.Drawing.Point  # readonly

    def Erase(self) -> None: ...
    def Dispose(self) -> None: ...
    def MoveTo(
        self, ctrl: System.Windows.Forms.Control, point: System.Drawing.Point
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Commands import ConversionType
from .Utils import SpectrumKey

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess

class CdbAccess(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessBase,
):  # Class
    def __init__(
        self,
        library: Agilent.MassSpectrometry.DataAnalysis.PCDLibrary,
        revisionNumber: str,
        lockKey: Any,
    ) -> None: ...

    CompoundCount: int  # readonly
    IsAccurateMass: bool
    IsReadOnly: bool  # readonly
    SpectrumCount: int  # readonly
    SuggestedConversionType: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType
    )  # readonly

    def DeleteSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def GetLibraryProperty(self, name: str) -> Any: ...
    def Sort(
        self,
        properties: List[str],
        ascending: bool,
        progress: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessReportSort,
        abort: System.Threading.WaitHandle,
    ) -> None: ...
    def SpectrumDisplayIndexOf(self, compoundId: int, spectrumId: int) -> int: ...
    def GetSpectrumTitle(self, compoundId: int, spectrumId: int) -> str: ...
    def SetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str, value_: Any
    ) -> None: ...
    def NewSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def GetCompoundIdFromIndex(self, dataIndex: int) -> int: ...
    def SetLibraryProperty(self, name: str, value_: Any) -> None: ...
    def GetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str
    ) -> Any: ...
    def GetSpectrumIds(self, compoundId: int) -> List[int]: ...
    def DeleteCompound(self, compoundId: int) -> None: ...
    def GetCompoundProperty(self, compoundId: int, name: str) -> Any: ...
    def ExportToJCAMP(self, file: str, spectrumKeys: List[SpectrumKey]) -> None: ...
    def SetCompoundProperty(self, compoundId: int, name: str, value_: Any) -> None: ...
    def Exists(self, compoundId: int, spectrumId: int) -> bool: ...
    def SaveAs(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        library: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        converesion: ConversionType,
    ) -> None: ...
    def FindNextNewCompoundId(self) -> int: ...
    def NewCompound(self, compoundId: int, displayIndex: int) -> None: ...
    def Save(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

class CompressLibraryAccess(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessBase,
):  # Class
    def __init__(
        self,
        library: Agilent.MassSpectrometry.DataAnalysis.MSLibrary,
        revisionNumber: str,
        lockKey: Any,
    ) -> None: ...

    CompoundCount: int  # readonly
    IsAccurateMass: bool
    SpectrumCount: int  # readonly
    SuggestedConversionType: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType
    )  # readonly

    def DeleteSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def GetLibraryProperty(self, name: str) -> Any: ...
    def SpectrumDisplayIndexOf(self, compoundId: int, spectrumId: int) -> int: ...
    def GetSpectrumTitle(self, compoundId: int, spectrumId: int) -> str: ...
    def SetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str, value_: Any
    ) -> None: ...
    def NewSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def GetCompoundIdFromIndex(self, dataIndex: int) -> int: ...
    def SetLibraryProperty(self, name: str, value_: Any) -> None: ...
    def GetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str
    ) -> Any: ...
    def GetSpectrumIds(self, compoundId: int) -> List[int]: ...
    def DeleteCompound(self, compoundId: int) -> None: ...
    def GetCompoundProperty(self, compoundId: int, name: str) -> Any: ...
    def ExportToJCAMP(self, file: str, spectrumKeys: List[SpectrumKey]) -> None: ...
    def SetCompoundProperty(self, compoundId: int, name: str, value_: Any) -> None: ...
    def Exists(self, compoundId: int, spectrumId: int) -> bool: ...
    def SaveAs(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        library: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        conversion: ConversionType,
    ) -> None: ...
    def FindNextNewCompoundId(self) -> int: ...
    def NewCompound(self, compoundId: int, displayIndex: int) -> None: ...
    def Save(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

class ContainsOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self, ignoreCase: bool) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class DataSetAccess(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessBase,
):  # Class
    def __init__(
        self,
        library: Agilent.MassSpectrometry.DataAnalysis.ILibrary,
        revisionNumber: str,
        lockKey: Any,
    ) -> None: ...

    CompoundCount: int  # readonly
    IsAccurateMass: bool
    MassSpecLibrary: Agilent.MassSpectrometry.DataAnalysis.MassSpecLibrary  # readonly
    SpectrumCount: int  # readonly
    SuggestedConversionType: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType
    )  # readonly

    def DeleteSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def GetLibraryProperty(self, name: str) -> Any: ...
    def SpectrumDisplayIndexOf(self, compoundId: int, spectrumId: int) -> int: ...
    def GetSpectrumTitle(self, compoundId: int, spectrumId: int) -> str: ...
    def SetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str, value_: Any
    ) -> None: ...
    def NewSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def GetCompoundIdFromIndex(self, dataIndex: int) -> int: ...
    def SetLibraryProperty(self, name: str, value_: Any) -> None: ...
    def GetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str
    ) -> Any: ...
    def GetSpectrumIds(self, compoundId: int) -> List[int]: ...
    def DeleteCompound(self, compoundId: int) -> None: ...
    def GetCompoundProperty(self, compoundId: int, name: str) -> Any: ...
    def ExportToJCAMP(self, file: str, spectrumKeys: List[SpectrumKey]) -> None: ...
    def SetCompoundProperty(self, compoundId: int, name: str, value_: Any) -> None: ...
    def Exists(self, compoundId: int, spectrumId: int) -> bool: ...
    def SaveAs(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        library: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        conversion: ConversionType,
    ) -> None: ...
    def FindNextNewCompoundId(self) -> int: ...
    def Convert(
        self, infoType: Agilent.MassSpectrometry.DataAnalysis.LibraryRTInfoType
    ) -> None: ...
    def NewCompound(self, compoundId: int, displayIndex: int) -> None: ...
    def Save(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

class DisplayList(System.IDisposable):  # Class
    def Dispose(self) -> None: ...

class EqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self, ignoreCase: bool) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class GreaterEqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class GreaterOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class IsNullOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class LessEqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class LessOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class LibraryAccessBase(System.MarshalByRefObject, System.IDisposable):  # Class
    AutoClose: bool
    CompoundCount: int  # readonly
    DisplayedCompoundCount: int  # readonly
    IsAccurateMass: bool
    IsReadOnly: bool  # readonly
    LibraryPath: str
    SpectrumCount: int  # readonly
    StorageFormat: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat  # readonly
    SuggestedConversionType: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType
    )  # readonly

    def FindNextNewCompoundId(self) -> int: ...
    def GetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str
    ) -> Any: ...
    def Sort(
        self,
        properties: List[str],
        ascending: bool,
        progress: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessReportSort,
        abort: System.Threading.WaitHandle,
    ) -> None: ...
    def Exists(self, compoundId: int, spectrumId: int) -> bool: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def OpenLibrary(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        revisionNumber: str,
        readOnly: bool,
        lockKey: Any,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessBase
    ): ...
    def GetSpectrumTitle(self, compoundId: int, spectrumId: int) -> str: ...
    def GetLibraryProperty(self, name: str) -> Any: ...
    def GetSpectrumIds(self, compoundId: int) -> List[int]: ...
    def GetCompoundIdFromIndex(self, dataIndex: int) -> int: ...
    def Save(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...
    def NewCompound(self, compoundId: int, displayIndex: int) -> None: ...
    def Search(
        self,
        conditions: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchConditions,
        progress: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessReportSearch,
        abort: System.Threading.WaitHandle,
    ) -> None: ...
    def SetLibraryProperty(self, name: str, value_: Any) -> None: ...
    def GetCompoundIdFromDisplayIndex(self, displayIndex: int) -> int: ...
    @staticmethod
    def CreateLibrary(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        lockKey: Any,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessBase
    ): ...
    def DeleteCompound(self, compoundId: int) -> None: ...
    def ClearSearch(self) -> None: ...
    def SetCompoundProperty(self, compoundId: int, name: str, value_: Any) -> None: ...
    def NewSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def DeleteSpectrum(self, compoundId: int, spectrumId: int) -> None: ...
    def GetCompoundProperty(self, compoundId: int, name: str) -> Any: ...
    def SpectrumDisplayIndexOf(self, compoundId: int, spectrumId: int) -> int: ...
    def SetSpectrumProperty(
        self, compoundId: int, spectrumId: int, name: str, value_: Any
    ) -> None: ...
    def ExportToJCAMP(self, file: str, spectrumKeys: List[SpectrumKey]) -> None: ...
    def CompoundDisplayIndexOf(self, compoundId: int) -> int: ...
    def SaveAs(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        library: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        conversion: ConversionType,
    ) -> None: ...

class LibraryAccessReportSearch(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        percent: float,
        countChanged: bool,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, percent: float, countChanged: bool) -> None: ...

class LibraryAccessReportSort(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self, percent: float, callback: System.AsyncCallback, object: Any
    ) -> System.IAsyncResult: ...
    def Invoke(self, percent: float) -> None: ...

class NotContainsOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self, ignoreCase: bool) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class NotEqualOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self, ignoreCase: bool) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class NotNullOperator(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
):  # Class
    def __init__(self) -> None: ...
    def Match(self, value1: Any, value2: Any) -> bool: ...

class SearchCondition:  # Class
    def __init__(
        self,
        property: str,
        isSpectrum: bool,
        type: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType,
        value_: Any,
        ignoreCase: Optional[bool],
    ) -> None: ...
    def Match(
        self,
        access: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessBase,
        compoundId: int,
    ) -> bool: ...

class SearchConditions:  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly

    def Match(
        self,
        access: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.LibraryAccessBase,
        compoundId: int,
    ) -> bool: ...
    def Add(
        self,
        condition: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchCondition,
    ) -> None: ...

class SearchOperator:  # Class
    def Match(self, value1: Any, value2: Any) -> bool: ...
    @staticmethod
    def Create(
        type: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType,
        ignoreStringCase: Optional[bool],
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperator
    ): ...
    @staticmethod
    def RequiresValue(
        type: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType,
    ) -> bool: ...

class SearchOperatorType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Contains: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    Equal: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    Greater: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    GreaterEqual: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    IsNull: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    Less: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    LessEqual: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    NotContains: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    NotEqual: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly
    NotNull: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SearchOperatorType
    ) = ...  # static # readonly

class SuggestedConversionType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    RTRI_L_RI: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType
    ) = ...  # static # readonly
    RTRI_L_RTL: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType
    ) = ...  # static # readonly
    RTRI_XML: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.DataAccess.SuggestedConversionType
    ) = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import ComplianceECM

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM.UI

class BatchDialog(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IBatchDialog,
    System.IDisposable,
):  # Class
    AllowFileRevisions: bool
    AuditTrail: bool
    BatchFile: str  # readonly
    BatchFolder: str  # readonly
    FileDialogMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    InitialFolder: str
    ReadOnly: bool  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class FileAndFolderDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IFileAndFolderDialog,
):  # Class
    Filters: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileAndFolderFilter
    ]
    InitialFolder: str
    Mode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    PathName: str  # readonly
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class FileDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IFileDialog,
):  # Class
    DefaultExtension: str
    DefaultFileName: str
    FileMustExists: bool
    Filters: str
    InitialFolder: str
    Mode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    MultiSelect: bool
    OverwritePrompt: bool
    PathName: str  # readonly
    PathNames: List[str]  # readonly
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class FolderDialog(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IFolderDialog,
    System.IDisposable,
):  # Class
    InitialFolder: str
    PathName: str  # readonly
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class LibraryDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.ILibraryDialog,
):  # Class
    def __init__(
        self,
        compliance: ComplianceECM,
        mode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode,
    ) -> None: ...

    AllowFileRevisions: bool
    AllowNistLibraries: bool
    ExtraFileFilter: str
    InitialFolder: str
    Mode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    PathName: str  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def AllowReferenceLibrary(self) -> None: ...
    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class LogonDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.ILogonDialog,
):  # Class
    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance
    )  # readonly
    Domain: str
    Handle: System.IntPtr  # readonly
    LogonXml: str  # readonly
    Message: str
    Owner: System.Windows.Window
    Password: System.Security.SecureString
    Server: str
    User: str
    ValidationMode: bool

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

    Cancel: System.ComponentModel.CancelEventHandler  # Event
    Logon: System.ComponentModel.CancelEventHandler  # Event

class MethodDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IMethodDialog,
):  # Class
    AllowFileRevisions: bool
    FileDialogMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    FileMustNotExist: bool
    IndividualFileExtensions: List[str]
    InitialFolder: str
    PathName: str  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

    SaveAsFolder: System.ComponentModel.CancelEventHandler  # Event

class SampleFileDialog(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.ISampleFileDialog,
    System.IDisposable,
):  # Class
    InitialFolder: str
    MultiSelect: bool
    PathName: str  # readonly
    PathNames: List[str]  # readonly
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...

class SaveBatchDialog(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    BatchFile: str
    BatchFolder: str
    InitialFolder: str
    SaveAsMode: bool

    def InitializeComponent(self) -> None: ...

class UnknownsFileDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IUnknownsFileDialog,
):  # Class
    AllowFileRevisions: bool
    AnalysisFile: str  # readonly
    AuditTrail: bool
    BatchFolder: str  # readonly
    FileDialogMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.FileDialogMode
    )  # readonly
    InitialFolder: str
    ReadOnly: bool  # readonly
    RevisionNumber: str  # readonly
    Title: str

    def Dispose(self) -> None: ...
    def ShowDialog(
        self, parent: System.Windows.Forms.IWin32Window
    ) -> System.Windows.Forms.DialogResult: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
TKey = TypeVar("TKey")
TValue = TypeVar("TValue")

# Stubs for namespace: System.util.collections

class HashSet2(Generic[T], Iterable[Any], Sequence[T], Iterable[T]):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, set: Iterable[T]) -> None: ...

    Count: int  # readonly
    IsReadOnly: bool  # readonly

    def GetEnumerator(self) -> Iterator[T]: ...
    def Contains(self, item: T) -> bool: ...
    def CopyTo(self, array: List[T], arrayIndex: int) -> None: ...
    def Add(self, item: T) -> None: ...
    def AddAll(self, set: Iterable[T]) -> None: ...
    def Clear(self) -> None: ...
    def Remove(self, item: T) -> bool: ...
    def IsEmpty(self) -> bool: ...
    def RetainAll(self, collection: Sequence[T]) -> bool: ...

class LinkedDictionary(
    Generic[TKey, TValue],
    Iterable[System.Collections.Generic.KeyValuePair[TKey, TValue]],
    Sequence[System.Collections.Generic.KeyValuePair[TKey, TValue]],
    Iterable[Any],
    Dict[TKey, TValue],
):  # Class
    def __init__(self) -> None: ...
    def __getitem__(self, key: TKey) -> TValue: ...
    def __setitem__(self, key: TKey, value_: TValue) -> None: ...
    Keys: Sequence[TKey]  # readonly
    Values: Sequence[TValue]  # readonly

    def TryGetValue(self, key: TKey, value_: TValue) -> bool: ...
    def Add(self, key: TKey, value_: TValue) -> None: ...
    def ContainsKey(self, key: TKey) -> bool: ...
    def Remove(self, key: TKey) -> bool: ...

    # Nested Types

    class KeyCollection(
        Generic[TKey, TValue], Iterable[Any], Iterable[TKey], Sequence[TKey]
    ):  # Class
        def __init__(
            self,
            link: System.Collections.Generic.LinkedList[
                System.Collections.Generic.KeyValuePair[TKey, TValue]
            ],
            dic: Dict[
                TKey,
                System.Collections.Generic.LinkedListNode[
                    System.Collections.Generic.KeyValuePair[TKey, TValue]
                ],
            ],
        ) -> None: ...

        Count: int  # readonly
        IsReadOnly: bool  # readonly

        def GetEnumerator(self) -> Iterator[TKey]: ...
        def Contains(self, item: TKey) -> bool: ...
        def CopyTo(self, array: List[TKey], arrayIndex: int) -> None: ...
        def Add(self, item: TKey) -> None: ...
        def Clear(self) -> None: ...
        def Remove(self, item: TKey) -> bool: ...

        # Nested Types

        class Enumerator(
            Generic[TKey, TValue], Iterator[Any], System.IDisposable, Iterator[TKey]
        ):  # Struct
            def __init__(
                self,
                link: System.Collections.Generic.LinkedList[
                    System.Collections.Generic.KeyValuePair[TKey, TValue]
                ],
            ) -> None: ...

            Current: TKey  # readonly

            def MoveNext(self) -> bool: ...
            def Reset(self) -> None: ...
            def Dispose(self) -> None: ...

    class ValueCollection(
        Generic[TKey, TValue], Iterable[Any], Sequence[TValue], Iterable[TValue]
    ):  # Class
        def __init__(
            self,
            link: System.Collections.Generic.LinkedList[
                System.Collections.Generic.KeyValuePair[TKey, TValue]
            ],
        ) -> None: ...

        Count: int  # readonly
        IsReadOnly: bool  # readonly

        def GetEnumerator(self) -> Iterator[TValue]: ...
        def Contains(self, item: TValue) -> bool: ...
        def CopyTo(self, array: List[TValue], arrayIndex: int) -> None: ...
        def Add(self, item: TValue) -> None: ...
        def Clear(self) -> None: ...
        def Remove(self, item: TValue) -> bool: ...

        # Nested Types

        class Enumerator(
            Generic[TKey, TValue], Iterator[Any], System.IDisposable, Iterator[TValue]
        ):  # Struct
            def __init__(
                self,
                link: System.Collections.Generic.LinkedList[
                    System.Collections.Generic.KeyValuePair[TKey, TValue]
                ],
            ) -> None: ...

            Current: TValue  # readonly

            def MoveNext(self) -> bool: ...
            def Reset(self) -> None: ...
            def Dispose(self) -> None: ...

class OrderedTree:  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    def __getitem__(self, key: System.IComparable) -> Any: ...
    def __setitem__(self, key: System.IComparable, value_: Any) -> None: ...
    Keys: System.util.collections.OrderedTreeEnumerator  # readonly
    Values: System.util.collections.OrderedTreeEnumerator  # readonly

    def GetEnumerator(self) -> System.util.collections.OrderedTreeEnumerator: ...
    def RemoveMax(self) -> None: ...
    def GetMaxKey(self) -> System.IComparable: ...
    def RemoveMin(self) -> None: ...
    def Add(self, key: System.IComparable, data: Any) -> None: ...
    @overload
    def Elements(self) -> System.util.collections.OrderedTreeEnumerator: ...
    @overload
    def Elements(
        self, ascending: bool
    ) -> System.util.collections.OrderedTreeEnumerator: ...
    def GetMaxValue(self) -> Any: ...
    def GetMinKey(self) -> System.IComparable: ...
    def GetMinValue(self) -> Any: ...
    def RotateLeft(self, x: System.util.collections.OrderedTreeNode) -> None: ...
    def GetData(self, key: System.IComparable) -> Any: ...
    def Clear(self) -> None: ...
    def ContainsKey(self, key: System.IComparable) -> bool: ...
    def Remove(self, key: System.IComparable) -> None: ...
    def IsEmpty(self) -> bool: ...
    def KeyElements(
        self, ascending: bool
    ) -> System.util.collections.OrderedTreeEnumerator: ...
    def RotateRight(self, x: System.util.collections.OrderedTreeNode) -> None: ...

class OrderedTreeEnumerator(Iterator[Any]):  # Class
    def __init__(
        self,
        tnode: System.util.collections.OrderedTreeNode,
        keys: bool,
        ascending: bool,
        sentinelNode: System.util.collections.OrderedTreeNode,
    ) -> None: ...

    Current: Any  # readonly
    Key: System.IComparable
    Value: Any

    def GetEnumerator(self) -> System.util.collections.OrderedTreeEnumerator: ...
    def Reset(self) -> None: ...
    def HasMoreElements(self) -> bool: ...
    def MoveNext(self) -> bool: ...
    def NextElement(self) -> Any: ...

class OrderedTreeNode:  # Class
    def __init__(self) -> None: ...

    BLACK: bool = ...  # static # readonly
    RED: bool = ...  # static # readonly

    Color: bool
    Data: Any
    Key: System.IComparable
    Left: System.util.collections.OrderedTreeNode
    Parent: System.util.collections.OrderedTreeNode
    Right: System.util.collections.OrderedTreeNode

class ReadOnlyDictionary(
    Generic[TKey, TValue],
    Sequence[System.Collections.Generic.KeyValuePair[TKey, TValue]],
    Dict[TKey, TValue],
    Iterable[Any],
    Sequence[Any],
    Iterable[System.Collections.Generic.KeyValuePair[TKey, TValue]],
):  # Class
    def __init__(self, dictionaryToWrap: Dict[TKey, TValue]) -> None: ...

    Count: int  # readonly
    def __getitem__(self, key: TKey) -> TValue: ...
    def __setitem__(self, key: TKey, value_: TValue) -> None: ...
    Keys: Sequence[TKey]  # readonly
    Values: Sequence[TValue]  # readonly

    def TryGetValue(self, key: TKey, value_: TValue) -> bool: ...
    def ContainsKey(self, key: TKey) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import IApplicationMenu2010Content

# Stubs for namespace: Agilent.MassHunter.Quantitative.Controls.OpenBatch

class BrowseDataStorageItem:  # Class
    def __init__(self) -> None: ...

    DateModified: Optional[System.DateTime]
    DateUploaded: Optional[System.DateTime]
    DisplayName: str
    Image: System.Windows.Media.ImageSource
    IsFolder: bool
    Name: str
    PathName: str

class BrowseDataStorageView(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IStyleConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class BrowseDataStorageViewModel(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewModel,
    ) -> None: ...

    CurrentFolderProperty: System.Windows.DependencyProperty  # static # readonly
    ItemRowContextMenuProperty: System.Windows.DependencyProperty  # static
    ItemsProperty: System.Windows.DependencyProperty  # static # readonly

    CommandBrowse: System.Windows.Input.ICommand  # readonly
    CommandGoUp: System.Windows.Input.ICommand  # readonly
    CurrentFolder: (
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.BrowseDataStorageItem
    )  # readonly
    IsDateModifiedVisibility: System.Windows.Visibility  # readonly
    IsDateUploadedVisibility: System.Windows.Visibility  # readonly
    ItemRowContextMenu: System.Windows.Controls.ContextMenu
    Items: List[
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.BrowseDataStorageItem
    ]

    def SetCurrentFolder(self, folder: str) -> None: ...

class OpenBatchView(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    IApplicationMenu2010Content,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewModel,
    ) -> None: ...

    RecentBatchesLabel: str

    def InitializeComponent(self) -> None: ...
    def SetSize(self, width: float, height: float) -> None: ...

class OpenBatchViewModel(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    CurrentViewModelProperty: System.Windows.DependencyProperty  # static # readonly
    InitialFolderProperty: System.Windows.DependencyProperty  # static # readonly
    RecentBatchesLabelProperty: System.Windows.DependencyProperty  # static # readonly
    RecentBatchesProperty: System.Windows.DependencyProperty  # static # readonly
    TitleProperty: System.Windows.DependencyProperty  # static # readonly

    BatchFile: str
    BatchFolder: str
    BrowseDataStorageViewModel: (
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.BrowseDataStorageViewModel
    )  # readonly
    CommandBrowse: System.Windows.Input.ICommand  # readonly
    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance
    )  # readonly
    CurrentViewModel: Any
    CurrentViewType: (
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewType
    )
    InitialFolder: str
    IsReadOnly: bool
    RecentBatches: List[str]
    RecentBatchesLabel: str
    RecentViewModel: (
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.RecentViewModel
    )  # readonly
    RevisionNumber: str
    Title: str
    ViewModels: List[
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewModelItem
    ]  # readonly

    def GetView(self) -> System.Windows.Controls.Control: ...
    def SetCurrentFolder(self, folder: str) -> None: ...
    def DoBrowse(self, folder: str) -> None: ...
    def FireBatchFileSelected(self) -> None: ...
    def GetDataFiles(
        self, folder: str
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.IFileInfo
    ]: ...
    def CreateRecentViewModel(
        self,
    ) -> Agilent.MassHunter.Quantitative.Controls.OpenBatch.RecentViewModel: ...

    BatchFileSelected: System.EventHandler  # Event

class OpenBatchViewModelItem(System.Windows.DependencyObject):  # Class
    def __init__(self) -> None: ...

    Image: System.Windows.Media.ImageSource
    Label: str
    ViewType: Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewType

class OpenBatchViewType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Computer: Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewType = (
        ...
    )  # static # readonly
    RecentBatches: (
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewType
    ) = ...  # static # readonly

class RecentBatchItem:  # Class
    def __init__(self) -> None: ...

    BatchFile: str
    BatchFolder: str
    DateModified: Optional[System.DateTime]
    Pathname: str

class RecentView(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IStyleConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class RecentViewModel(System.Windows.DependencyObject):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewModel,
    ) -> None: ...

    ItemRowContextMenuProperty: System.Windows.DependencyProperty  # static
    RecentBatchesProperty: System.Windows.DependencyProperty  # static

    ItemRowContextMenu: System.Windows.Controls.ContextMenu
    Model: (
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.OpenBatchViewModel
    )  # readonly
    RecentBatches: List[
        Agilent.MassHunter.Quantitative.Controls.OpenBatch.RecentBatchItem
    ]  # readonly
    RecentBatchesLabel: str  # readonly
    SelectedItem: Agilent.MassHunter.Quantitative.Controls.OpenBatch.RecentBatchItem

    def ItemClicked(
        self, item: Agilent.MassHunter.Quantitative.Controls.OpenBatch.RecentBatchItem
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: AGaugeApp

class AGauge(
    System.IDisposable,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.Control,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
):  # Class
    def __init__(self) -> None: ...

    AllowDrop: bool
    AutoSize: bool
    BackColor: System.Drawing.Color
    BackgroundImageLayout: System.Windows.Forms.ImageLayout
    BaseArcColor: System.Drawing.Color
    BaseArcRadius: int
    BaseArcStart: int
    BaseArcSweep: int
    BaseArcWidth: int
    CapColors: List[System.Drawing.Color]
    CapPosition: System.Drawing.Point
    CapText: str
    Cap_Idx: int
    CapsPosition: List[System.Drawing.Point]
    CapsText: List[str]
    Center: System.Drawing.Point
    Font: System.Drawing.Font
    ForeColor: bool
    ImeMode: bool
    MaxValue: float
    MinValue: float
    NeedleColor1: AGaugeApp.AGauge.NeedleColorEnum
    NeedleColor2: System.Drawing.Color
    NeedleRadius: int
    NeedleType: int
    NeedleWidth: int
    RangeColor: System.Drawing.Color
    RangeEnabled: bool
    RangeEndValue: float
    RangeInnerRadius: int
    RangeOuterRadius: int
    RangeStartValue: float
    Range_Idx: int
    RangesColor: List[System.Drawing.Color]
    RangesEnabled: List[bool]
    RangesEndValue: List[float]
    RangesInnerRadius: List[int]
    RangesOuterRadius: List[int]
    RangesStartValue: List[float]
    ScaleLinesInterColor: System.Drawing.Color
    ScaleLinesInterInnerRadius: int
    ScaleLinesInterOuterRadius: int
    ScaleLinesInterWidth: int
    ScaleLinesMajorColor: System.Drawing.Color
    ScaleLinesMajorInnerRadius: int
    ScaleLinesMajorOuterRadius: int
    ScaleLinesMajorStepValue: float
    ScaleLinesMajorWidth: int
    ScaleLinesMinorColor: System.Drawing.Color
    ScaleLinesMinorInnerRadius: int
    ScaleLinesMinorNumOf: int
    ScaleLinesMinorOuterRadius: int
    ScaleLinesMinorWidth: int
    ScaleNumbersColor: System.Drawing.Color
    ScaleNumbersFormat: str
    ScaleNumbersRadius: int
    ScaleNumbersRotation: int
    ScaleNumbersStartScaleLine: int
    ScaleNumbersStepScaleLines: int
    Value: float

    ValueInRangeChanged: AGaugeApp.AGauge.ValueInRangeChangedDelegate  # Event

    # Nested Types

    class NeedleColorEnum(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Blue: AGaugeApp.AGauge.NeedleColorEnum = ...  # static # readonly
        Gray: AGaugeApp.AGauge.NeedleColorEnum = ...  # static # readonly
        Green: AGaugeApp.AGauge.NeedleColorEnum = ...  # static # readonly
        Magenta: AGaugeApp.AGauge.NeedleColorEnum = ...  # static # readonly
        Red: AGaugeApp.AGauge.NeedleColorEnum = ...  # static # readonly
        Violet: AGaugeApp.AGauge.NeedleColorEnum = ...  # static # readonly
        Yellow: AGaugeApp.AGauge.NeedleColorEnum = ...  # static # readonly

    class ValueInRangeChangedDelegate(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: AGaugeApp.AGauge.ValueInRangeChangedEventArgs,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self, sender: Any, e: AGaugeApp.AGauge.ValueInRangeChangedEventArgs
        ) -> None: ...

    class ValueInRangeChangedEventArgs(System.EventArgs):  # Class
        def __init__(self, valueInRange: int) -> None: ...

        valueInRange: int



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Utilities.StreamProxies

class AcamlStreamProxy(
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Interfaces.IAcamlStreamProxy,
    System.IDisposable,
    Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Utilities.StreamProxies.StreamProxyBase,
):  # Class
    def __init__(self, verifyChecksum: bool, validateSchema: bool) -> None: ...
    @overload
    def Read(
        self,
        storageFileAccess: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
        path: str,
    ) -> bool: ...
    @overload
    def Read(self, stream: System.IO.Stream) -> bool: ...

class StreamProxyBase(System.IDisposable):  # Class
    FileBasedStream: System.IO.Stream  # readonly
    TempFilePath: str  # readonly

    @overload
    def Read(
        self,
        storageFileAccess: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
        path: str,
    ) -> bool: ...
    @overload
    def Read(self, stream: System.IO.Stream) -> bool: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report

class GraphicsFileMap:  # Class
    def __init__(self) -> None: ...
    def GetFile(
        self,
        rowID: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.RowID,
        fileType: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report.GraphicsFileType,
    ) -> str: ...
    def SetFile(
        self,
        rowID: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.RowID,
        fileType: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report.GraphicsFileType,
        file: str,
    ) -> None: ...

class GraphicsFileType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ComponentSpectrum: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report.GraphicsFileType
    ) = ...  # static # readonly
    HitLibrarySpectrum: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report.GraphicsFileType
    ) = ...  # static # readonly
    SampleChromatogram: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report.GraphicsFileType
    ) = ...  # static # readonly

class IReportGraphics(System.IDisposable):  # Interface
    def SetContext(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandContext,
    ) -> None: ...
    def DrawComponentIonPeaks(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawSampleChromatogram(
        self,
        batchID: int,
        sampleID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawHitLibrarySpectrum(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawComponentSpectrum(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawIonPeakChromatogram(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        ionPeakID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawComponentChromatogram(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...

class ReportGraphics(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report.IReportGraphics,
    System.IDisposable,
):  # Class
    def __init__(self) -> None: ...
    def SetContext(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandContext,
    ) -> None: ...
    def DrawComponentIonPeaks(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawSampleChromatogram(
        self,
        batchID: int,
        sampleID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawHitLibrarySpectrum(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawComponentSpectrum(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawIonPeakChromatogram(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        ionPeakID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def DrawComponentChromatogram(
        self,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        stream: System.IO.Stream,
        sizeInches: System.Drawing.SizeF,
    ) -> None: ...
    def Dispose(self) -> None: ...

class ResultsWriter:  # Class
    def __init__(
        self,
        dataFile: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataFile.DataFileBase,
        batchID: Optional[int],
        sampleID: Optional[int],
        writer: System.Xml.XmlWriter,
        fileMap: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Report.GraphicsFileMap,
    ) -> None: ...
    def Write(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO

class CefFileReader:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Open(
        fullFileName: str,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO.ICefFile: ...

class ICefCompound(object):  # Interface
    BasePeakAbundance: str  # readonly
    CasNumber: str  # readonly
    FeatureFindingAlgorithm: str  # readonly
    Formula: str  # readonly
    Name: str  # readonly
    NeutralMass: float  # readonly
    RetentionTimeInMinutes: float  # readonly

    def GetFragmentIonConfirmation(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO.ICefFragmentIonConfirmation
    ): ...
    def GetSpectrum(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO.ICefSpectrum: ...

class ICefFile(System.IDisposable):  # Interface
    def GetNextCompound(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO.ICefCompound: ...
    def GCQTOF(self) -> bool: ...

class ICefFragmentIonConfirmation(object):  # Interface
    FragmentIonPeaks: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO.ICefFragmentIonPeak
    ]
    IonPolarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity

class ICefFragmentIonPeak(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO.ICefPeak,
    System.IComparable,
):  # Interface
    CoelutionScore: Optional[float]  # readonly
    CollisionEnergy: Optional[float]  # readonly
    FragmentorVoltage: Optional[float]  # readonly
    LibraryAbundance: Optional[float]  # readonly

class ICefPeak(System.IComparable):  # Interface
    Intensity: float  # readonly
    MZ: float  # readonly

class ICefSpectrum(object):  # Interface
    CollisionEnergy: Optional[float]  # readonly
    FragmentorVoltage: Optional[float]  # readonly
    IonPolarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity
    MzOfInterest: float  # readonly
    Peaks: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CefFileIO.ICefPeak
    ]
    ScanType: str
    Type: str



# -*- coding: utf-8 -*-
from __future__ import (
    absolute_import,
    division,
    generators,
    nested_scopes,
    print_function,
    unicode_literals,
    with_statement,
)

import os
import shutil
import sys
import tempfile
from itertools import islice

from mh_operator.legacy.common import get_logger, global_state

logger = get_logger()

try:
    import clr

    clr.AddReference("CoreLibraryAccess")
    clr.AddReference("LibraryEdit")

    import _commands
    import System
    from Agilent.MassSpectrometry.DataAnalysis import MSLibraryFormat
    from Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands import (
        CompoundProperty,
    )

    libacc = global_state.LibraryAccess
except ImportError:
    assert sys.executable is not None, "Should never reach here"
    from mh_operator.SDK.Agilent.MassSpectrometry.DataAnalysis import MSLibraryFormat
    from mh_operator.SDK.Agilent.MassSpectrometry.DataAnalysis.LibraryEdit import (
        Commands as _commands,
    )
    from mh_operator.SDK.Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands import (
        CompoundProperty,
    )
    from mh_operator.SDK.Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.ScriptIf import (
        ILibraryAccess,
    )

    libacc = ILibraryAccess()


def import_jcamps(jdx_paths, output_path, overwrite=False, batch_size=100):
    with tempfile.NamedTemporaryFile(suffix=".bin", delete=True) as fp:
        temp_file = fp.name
    try:
        logger.debug("creating {}".format(temp_file))
        _commands.CreateLibrary(temp_file, MSLibraryFormat.Binary)

        it = iter(jdx_paths)
        total_batchs = len(jdx_paths) // batch_size
        for i in range(total_batchs):
            logger.debug("adding batch {}/{}".format(i, total_batchs))
            _commands.ImportJCAMP(
                System.Array[System.String](list(islice(it, batch_size)))
            )
            # _commands.NewCompound(System.Array[CompoundProperty]([CompoundProperty(-1, "CompoundName", "New compond from keyin")]))
        last_batch = list(islice(it, batch_size))
        if last_batch:
            logger.debug("adding rest {} jdx".format(len(last_batch)))
            _commands.ImportJCAMP(System.Array[System.String](last_batch))

        logger.info("Total {} Compounds added".format(libacc.CompoundCount))

        if overwrite:
            shutil.rmtree(output_path, ignore_errors=True)

        _commands.SaveLibraryAs(output_path, MSLibraryFormat.Compressed)
        _commands.CloseLibrary()
    finally:
        os.unlink(temp_file)


def compress_mslibrary(library_path, output_path=None):
    assert library_path.endswith(".mslibrary.xml")

    _commands.OpenLibrary(library_path, MSLibraryFormat.XML, True)
    logger.debug("#Compound = {}".format(libacc.CompoundCount))

    for c in range(libacc.CompoundCount):
        compoundId = libacc.GetCompoundId(c)
        spectrumIds = libacc.GetSpectrumIds(compoundId)
        logger.debug("Compound ID= {}".format(compoundId))
        logger.debug("Spectrum IDs= {}".format(spectrumIds))
        if spectrumIds is None:
            continue

        for spectrumId in spectrumIds:
            mz_b64 = libacc.GetSpectrumProperty(compoundId, spectrumId, "MzValues")
            abundance_b64 = libacc.GetSpectrumProperty(
                compoundId, spectrumId, "AbundanceValues"
            )

            if mz_b64 is None or abundance_b64 is None:
                continue

            mzs = libacc.Base64ToDoubleArray(mz_b64) if mz_b64 is not None else None
            abs = (
                libacc.Base64ToDoubleArray(abundance_b64)
                if abundance_b64 is not None
                else None
            )
            logger.debug("Mz = {}".format(mzs))
            logger.debug("Abundance = {}".format(abs))

    if output_path is None:
        output_path = library_path.replace(".mslibrary.xml", ".L")
    else:
        assert output_path.endswith(".L")

    _commands.SaveLibraryAs(output_path, MSLibraryFormat.Compressed)

    _commands.CloseLibrary()



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine

class Engine:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def RunScript(
        language: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.ScriptLanguage,
        stream: System.IO.Stream,
        variables: Dict[str, Any],
    ) -> None: ...

class IScriptEngine(object):  # Interface
    Globals: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope
    )  # readonly

    def GetSearchPaths(self) -> Sequence[str]: ...
    def CreateScope(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope
    ): ...
    @overload
    def Execute(
        self, reader: System.IO.TextReader, encoding: System.Text.Encoding
    ) -> Any: ...
    @overload
    def Execute(
        self,
        reader: System.IO.TextReader,
        encoding: System.Text.Encoding,
        scope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self, stream: System.IO.Stream, encoding: System.Text.Encoding
    ) -> Any: ...
    @overload
    def Execute(
        self,
        stream: System.IO.Stream,
        encoding: System.Text.Encoding,
        scope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(self, code: System.CodeDom.CodeObject) -> Any: ...
    def SetSearchPaths(self, paths: Sequence[str]) -> None: ...
    def ExecuteFile(
        self,
        file: str,
        scope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope,
    ) -> Any: ...

class IScriptScope(object):  # Interface
    def SetVariable(self, name: str, value_: Any) -> None: ...

class IronEngine(
    System.MarshalByRefObject,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptEngine,
):  # Class
    @overload
    def __init__(
        self,
        language: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.ScriptLanguage,
    ) -> None: ...
    @overload
    def __init__(self, engine: Any) -> None: ...

    Globals: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope
    )  # readonly
    _Globals: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.ScriptScope
    )  # readonly

    def GetSearchPaths(self) -> Sequence[str]: ...
    @overload
    def CreateScope(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope
    ): ...
    @overload
    def CreateScope(
        self, variables: Dict[str, Any]
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.ScriptScope
    ): ...
    @overload
    def Execute(
        self, reader: System.IO.TextReader, encoding: System.Text.Encoding
    ) -> Any: ...
    @overload
    def Execute(
        self,
        reader: System.IO.TextReader,
        encoding: System.Text.Encoding,
        iscope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(
        self, stream: System.IO.Stream, encoding: System.Text.Encoding
    ) -> Any: ...
    @overload
    def Execute(
        self,
        stream: System.IO.Stream,
        encoding: System.Text.Encoding,
        iscope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope,
    ) -> Any: ...
    @overload
    def Execute(self, code: System.CodeDom.CodeObject) -> Any: ...
    def SetSearchPaths(self, paths: Sequence[str]) -> None: ...
    def LoadAssembly(self, assembly: System.Reflection.Assembly) -> None: ...
    def Dispose(self) -> None: ...
    def ExecuteFile(
        self,
        file: str,
        iscope: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope,
    ) -> Any: ...

class ScriptLanguage(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    IronPython: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.ScriptLanguage
    ) = ...  # static # readonly

class ScriptScope(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ScriptEngine.IScriptScope
):  # Class
    def GetVariableNames(self) -> Iterable[str]: ...
    def RemoveVariable(self, name: str) -> None: ...
    def GetVariable(self, name: str) -> Any: ...
    def ContainsVariable(self, name: str) -> bool: ...
    def SetVariable(self, name: str, value_: Any) -> None: ...
